@@ -19,13 +19,6 @@ MAILJET_SECRET_KEY                                  = os.environ.get('MAILJET_SE
 
 CRYPTO_SECRET_KEY                                   = os.environ.get('CRYPTO_SECRET_KEY')
 
-TASK_GCLOUD_PROJECT_ID                              = os.environ.get('TASK_GCLOUD_PROJECT_ID')
-TASK_GCLOUD_LOCATION                                = os.environ.get('TASK_GCLOUD_LOCATION')
-TASK_SERVICE_ACCOUNT_KEY_FILEPATH                   = os.environ.get('TASK_SERVICE_ACCOUNT_KEY')
-TASK_SERVICE_CREDENTIAL_PATH                        = os.path.abspath(os.path.dirname(config_path.__file__)) + '/' + TASK_SERVICE_ACCOUNT_KEY_FILEPATH
-TASK_SERVICE_ACCOUNT_EMAIL                          = os.environ.get('TASK_SERVICE_ACCOUNT_EMAIL')
-
-
 BIGQUERY_GCLOUD_PROJECT_ID                          = os.environ.get('BIGQUERY_GCLOUD_PROJECT_ID')
 BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH               = os.environ.get('BIGQUERY_SERVICE_ACCOUNT_KEY')
 BIGQUERY_SERVICE_CREDENTIAL_PATH                    = os.path.abspath(os.path.dirname(config_path.__file__)) + '/' + BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH
