@@ -12,12 +12,13 @@ from google.protobuf import timestamp_pb2
 from trexlib.utils.security_util import create_basic_authentication, verfiy_basic_authentication
 from trexlib.utils.string_util import random_string
 
-logger = logging.getLogger('debug')
+logger = logging.getLogger('util')
 
-def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method='get', headers=None): 
+def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method='get', headers=None, 
+                credential_path=None, project_id=None, location=None, service_email=None): 
     
     cred = service_account.Credentials.from_service_account_file(
-                                                            lib_conf.TASK_SERVICE_CREDENTIAL_PATH,
+                                                            credential_path,
                                                             scopes=["https://www.googleapis.com/auth/cloud-platform", 
                                                                     "https://www.googleapis.com/auth/cloud-tasks"
                                                                     ]
@@ -27,15 +28,15 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
     
     client = tasks_v2.CloudTasksClient(credentials=cred)
         
-    parent = client.queue_path(lib_conf.TASK_GCLOUD_PROJECT_ID, lib_conf.TASK_GCLOUD_LOCATION, queue_name)
+    parent = client.queue_path(project_id, location, queue_name)
     
     logger.debug(">>>>>>>>>>>>>>>>create_task: task_url=%s", task_url)
     
     task = {
         "http_request": {  # Specify the type of request.
-                         "http_method"  : tasks_v2.HttpMethod.POST if http_method=='post' else tasks_v2.HttpMethod.GET,
+                         "http_method"  : tasks_v2.HttpMethod.POST if http_method.lower()=='post' or payload is not None else tasks_v2.HttpMethod.GET,
                          "url"          : task_url,  
-                         "oidc_token"   : {"service_account_email": lib_conf.TASK_SERVICE_ACCOUNT_EMAIL},
+                         "oidc_token"   : {"service_account_email": service_email},
                         }
         }
     
@@ -59,8 +60,8 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
             task["http_request"]["headers"][k]=v
             
     
-    task["http_request"]["headers"]['X-task-id']= task_id
-    task["http_request"]["headers"]['X-task-token']= create_task_authenticated_token(task_id)
+    task["http_request"]["headers"]['X-task-id']        = task_id
+    task["http_request"]["headers"]['X-task-token']     = create_task_authenticated_token(task_id)
         
     if in_seconds is not None:
         # Convert "seconds from now" into an rfc3339 datetime string.
